Documentation
¶
Overview ¶
Package htjson (honeytail-json, renamed to not conflict with the json module) parses logs that are one json blob per line.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type JSONLineParser ¶
type JSONLineParser struct {
}
type Options ¶
type Options struct {
TimeFieldName string `long:"timefield" description:"Name of the field that contains a timestamp"`
TimeFieldFormat string `long:"format" description:"Format of the timestamp found in timefield (supports strftime and Golang time formats)"`
NumParsers int `hidden:"true" description:"number of htjson parsers to spin up"`
}
Click to show internal directories.
Click to hide internal directories.