Documentation
¶
Overview ¶
Package keyval parses logs whose format is many key=val pairs
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type KeyValLineParser ¶
type KeyValLineParser struct {
}
type Options ¶
type Options struct {
TimeFieldName string `long:"timefield" description:"Name of the field that contains a timestamp"`
TimeFieldFormat string `long:"format" description:"Format of the timestamp found in timefield (supports strftime and Golang time formats)"`
FilterRegex string `long:"filter_regex" description:"a regular expression that will filter the input stream and only parse lines that match"`
InvertFilter bool `long:"invert_filter" description:"change the filter_regex to only process lines that do *not* match"`
NumParsers int `hidden:"true" description:"number of keyval parsers to spin up"`
}
Click to show internal directories.
Click to hide internal directories.